SchedulerTask
=============

.. currentmodule:: atqo

.. autoclass:: SchedulerTask
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SchedulerTask.init_future
      ~SchedulerTask.set_future

   .. rubric:: Methods Documentation

   .. automethod:: init_future
   .. automethod:: set_future
